@@ -62,17 +62,17 @@ Because Fiona collections are context managers, they are closed and (in
 writing modes) flush contents to disk when their ``with`` blocks end.
 """
 
-__all__ = ['listlayers', 'open', 'prop_type', 'prop_width']
-__version__ = "1.1.2"
+__all__ = ['bounds', 'listlayers', 'open', 'prop_type', 'prop_width']
+__version__ = "1.1.3"
 
 import logging
 import os
 from six import string_types
 
 from fiona.collection import Collection, supported_drivers, vsi_path
-from fiona._drivers import DriverManager, DummyManager, driver_count
+from fiona._drivers import driver_count, GDALEnv
 from fiona.odict import OrderedDict
-from fiona.ogrext import _listlayers, FIELD_TYPES_MAP
+from fiona.ogrext import _bounds, _listlayers, FIELD_TYPES_MAP
 
 
 log = logging.getLogger('Fiona')
@@ -220,12 +220,19 @@ def prop_type(text):
     key = text.split(':')[0]
     return FIELD_TYPES_MAP[key]
 
-def drivers(*args):
+def drivers(*args, **kwargs):
     """Returns a context manager with registered drivers."""
-    if driver_count() == 0:
-        log.debug("Creating a DriverManager in drivers()")
-        return DriverManager()
+    if driver_count == 0:
+        log.debug("Creating a chief GDALEnv in drivers()")
+        return GDALEnv(True, **kwargs)
     else:
-        log.debug("Creating a DummyManager in drivers()")
-        return DummyManager()
+        log.debug("Creating a not-responsible GDALEnv in drivers()")
+        return GDALEnv(False, **kwargs)
+
+def bounds(ob):
+    """Returns a (minx, miny, maxx, maxy) bounding box.
+    
+    The ``ob`` may be a feature record or geometry."""
+    geom = ob.get('geometry') or ob
+    return _bounds(geom)
 
